#ifndef GPIBLIB_H
#define GPIBLIB_H

#include "typedefs.h"

#ifdef __cplusplus
extern "C"
{
#endif

#ifdef BUILDING_GPIBLIB
   #define GPIBDEF __declspec(dllexport)
#else
   #define GPIBDEF __declspec(dllimport)
#endif

enum GPTIMEOUT
{
   TIMEOUT_TNONE  = 0,   /* Infinite timeout (disabled)   */
   TIMEOUT_T10us  = 1,   /* Timeout of 10 us (ideal)      */
   TIMEOUT_T30us  = 2,   /* Timeout of 30 us (ideal)      */
   TIMEOUT_T100us = 3,   /* Timeout of 100 us (ideal)     */
   TIMEOUT_T300us = 4,   /* Timeout of 300 us (ideal)     */
   TIMEOUT_T1ms   = 5,   /* Timeout of 1 ms (ideal)       */
   TIMEOUT_T3ms   = 6,   /* Timeout of 3 ms (ideal)       */
   TIMEOUT_T10ms  = 7,   /* Timeout of 10 ms (ideal)      */
   TIMEOUT_T30ms  = 8,   /* Timeout of 30 ms (ideal)      */
   TIMEOUT_T100ms = 9,   /* Timeout of 100 ms (ideal)     */
   TIMEOUT_T300ms =10,   /* Timeout of 300 ms (ideal)     */
   TIMEOUT_T1s    =11,   /* Timeout of 1 s (ideal)        */
   TIMEOUT_T3s    =12,   /* Timeout of 3 s (ideal)        */
   TIMEOUT_T10s   =13,   /* Timeout of 10 s (ideal)       */
   TIMEOUT_T30s   =14,   /* Timeout of 30 s (ideal)       */
   TIMEOUT_T100s  =15,   /* Timeout of 100 s (ideal)      */
   TIMEOUT_T300s  =16,   /* Timeout of 300 s (ideal)      */
   TIMEOUT_T1000s =17    /* Timeout of 1000 s (ideal)     */
};

typedef void (WINAPI *GPIBERR)   (C8 *msg, S32 ibsta, S32 iberr, S32 ibcntl);
                                                  
GPIBDEF S32    WINAPI GPIB_connect                 (S32        device_address, 
                                                    GPIBERR    handler, 
                                                    S32        clear                  = 0, 
                                                    GPTIMEOUT  timeout                = TIMEOUT_T100s, 
                                                    S32        board_address          = -1, 
                                                    S32        release_system_control = 0,
                                                    S32        max_read_buffer_len    = 4096);   // >4K will not work with NI GPIB-232!

GPIBDEF S32    WINAPI GPIB_disconnect              (BOOL32 reset_to_local = TRUE);
GPIBDEF S32    WINAPI GPIB_set_EOS_mode            (S32 new_EOS_char, BOOL32 send_EOI_at_EOT = TRUE);
GPIBDEF S32    WINAPI GPIB_write                   (C8 *string, S32 len=-1, BOOL32 to_board = FALSE, BOOL32 ignore_aborts = TRUE, BOOL32 append_CRLF = TRUE);
GPIBDEF S32    WINAPI GPIB_set_serial_read_timeout (S32 ms); 
GPIBDEF C8 *   WINAPI GPIB_serial_configuration    (S32 *controller_mode = NULL, S32 *device_addressable = NULL, S32 *host_addressable = NULL);
GPIBDEF C8 *   WINAPI GPIB_read_ASC                (S32 max_len=-1, BOOL32 report_timeout = TRUE, BOOL32 from_board = FALSE);
GPIBDEF C8 *   WINAPI GPIB_read_BIN                (S32 max_len=-1, BOOL32 report_timeout = TRUE, BOOL32 from_board = FALSE, S32 *actual_len = NULL);
GPIBDEF S32    WINAPI GPIB_status                  (BOOL32 from_board = FALSE);
GPIBDEF C8 *   WINAPI GPIB_query                   (C8 *string);
GPIBDEF C8     WINAPI GPIB_serial_poll             (void);
GPIBDEF S32    WINAPI GPIB_flush_receive_buffers   (void);

#ifdef __cplusplus
}
#endif

#endif
